@@ -6,7 +6,10 @@ from zshpower.config import package
 class Base:
     def __init__(self, home):
         self.HOME = home
-        self.config_root = join(self.HOME, f".config/snakypy/zshpower/{__version__}")
+        self.config_root = join(
+            self.HOME, f".{package.info['pkg_name']}/config/{__version__}"
+        )
+        self.init_file = join(self.HOME, f".{package.info['pkg_name']}/init")
         self.config_file = join(self.config_root, "config.toml")
         self.zsh_rc = join(self.HOME, ".zshrc")
         self.omz_root = join(self.HOME, ".oh-my-zsh")
